Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(538)

Unified Diff: include/gpu/GrContext.h

Issue 311183002: Push dash checks into GrContext. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Merge issues Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gyp/gpu.gypi ('k') | src/gpu/GrAARectRenderer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrContext.h
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h
index 41ee15917f44c60b71a3aecd7044debeea61aa57..c909907bfcc120a8a9272e1c838fa95cde221f27 100644
--- a/include/gpu/GrContext.h
+++ b/include/gpu/GrContext.h
@@ -39,6 +39,7 @@ class GrTestTarget;
class GrTextureParams;
class GrVertexBuffer;
class GrVertexBufferAllocPool;
+class GrStrokeInfo;
class GrSoftwarePathRenderer;
class SkStrokeRec;
@@ -452,18 +453,20 @@ public:
/**
* Draw the rect using a paint.
* @param paint describes how to color pixels.
* @param stroke the stroke information (width, join, cap).
* If stroke == NULL, then the rect is filled.
* Otherwise, if stroke width == 0, then the stroke
* is always a single pixel thick, else the rect is
* mitered/beveled stroked based on stroke width.
+ * If the stroke is dashed the rect is sent to drawPath.
* @param matrix Optional matrix applied to the rect. Applied before
* context's matrix or the paint's matrix.
* The rects coords are used to access the paint (through texture matrix)
*/
void drawRect(const GrPaint& paint,
const SkRect&,
- const SkStrokeRec* stroke = NULL,
+ const GrStrokeInfo* strokeInfo = NULL,
const SkMatrix* matrix = NULL);
/**
@@ -490,9 +493,10 @@ public:
*
* @param paint describes how to color pixels.
* @param rrect the roundrect to draw
* @param stroke the stroke information (width, join, cap)
*/
- void drawRRect(const GrPaint& paint, const SkRRect& rrect, const SkStrokeRec& stroke);
+ void drawRRect(const GrPaint& paint, const SkRRect& rrect, const GrStrokeInfo& strokeInfo);
/**
* Shortcut for drawing an SkPath consisting of nested rrects using a paint.
@@ -511,9 +515,10 @@ public:
*
* @param paint describes how to color pixels.
* @param path the path to draw
* @param stroke the stroke information (width, join, cap)
*/
- void drawPath(const GrPaint& paint, const SkPath& path, const SkStrokeRec& stroke);
+ void drawPath(const GrPaint& paint, const SkPath& path, const GrStrokeInfo& strokeInfo);
/**
* Draws vertices with a paint.
@@ -545,11 +550,12 @@ public:
*
* @param paint describes how to color pixels.
* @param oval the bounding rect of the oval.
- * @param stroke the stroke information (width, style)
+ * @param strokeInfo the stroke information (width, join, cap) and
+ * the dash information (intervals, count, phase).
*/
void drawOval(const GrPaint& paint,
const SkRect& oval,
- const SkStrokeRec& stroke);
+ const GrStrokeInfo& strokeInfo);
///////////////////////////////////////////////////////////////////////////
// Misc.
@@ -995,7 +1001,7 @@ private:
GrDrawTarget* prepareToDraw(const GrPaint*, BufferedDraw, AutoRestoreEffects*, AutoCheckFlush*);
void internalDrawPath(GrDrawTarget* target, bool useAA, const SkPath& path,
- const SkStrokeRec& stroke);
+ const GrStrokeInfo& stroke);
GrTexture* createResizedTexture(const GrTextureDesc& desc,
const GrCacheID& cacheID,
« no previous file with comments | « gyp/gpu.gypi ('k') | src/gpu/GrAARectRenderer.h » ('j') | no next file with comments »
@@ -452,18 +453,20 @@ public:
* Draw the rect using a paint.
* @param paint describes how to color pixels.
- * @param stroke the stroke information (width, join, cap).
- * If stroke == NULL, then the rect is filled.
+ * @param strokeInfo the stroke information (width, join, cap), and.
+ * the dash information (intervals, count, phase).
+ * If strokeInfo == NULL, then the rect is filled.
* Otherwise, if stroke width == 0, then the stroke
* is always a single pixel thick, else the rect is
@@ -490,9 +493,10 @@ public:
* @param paint describes how to color pixels.
* @param rrect the roundrect to draw
- * @param stroke the stroke information (width, join, cap)
+ * @param strokeInfo the stroke information (width, join, cap) and
+ * the dash information (intervals, count, phase).
*/
@@ -511,9 +515,10 @@ public:
* @param paint describes how to color pixels.
* @param path the path to draw
- * @param stroke the stroke information (width, join, cap)
+ * @param strokeInfo the stroke information (width, join, cap) and
+ * the dash information (intervals, count, phase).
*/

Powered by Google App Engine
This is Rietveld 408576698